@@ -16,7 +16,7 @@ def make_trainval_config(
         USE_tqdm_TRAIN = cfg.USE_tqdm_TRAIN
         INPUT_SIZE = (cfg.INPUT_W, cfg.INPUT_H)
         BATCH_SIZE = cfg.BATCH_SIZE
-        NUM_EPOCHS = cfg.NUM_EPOCHS
+        MAX_EPOCHS = cfg.MAX_EPOCHS
         BALANCE_CLASSES = cfg.BALANCE_CLASSES
         VAL_INTERVAL = cfg.VAL_INTERVAL
         WEIGHTS_SAVE_INTERVAL = cfg.WEIGHTS_SAVE_INTERVAL
@@ -54,15 +54,15 @@ models = [
     models_names.shufflenet_v2_x1_0,
 ]
 
-def get_base_config():
+def get_base_config(train_dir='/home/ars/sda5/data/projects/烟分类/data/烟分类-train',val_dir='/home/ars/sda5/data/projects/烟分类/data/烟分类-val'):
     base_config = dict(
         MODEL_TYPE=VirtualField(title='模型', description='选择模型', default='resnet18', options=models),
-        TRAIN_DIR=SelectDir('/home/ars/sda5/data/projects/烟分类/data/烟分类-train'),
-        VAL_DIR=SelectDir('/home/ars/sda5/data/projects/烟分类/data/烟分类-val'),
+        TRAIN_DIR=SelectDir(train_dir),
+        VAL_DIR=SelectDir(val_dir),
         GEN_CLASSES_FILE=VirtualField(default=True, title='生成类别文件'),
         USE_tqdm_TRAIN=True,
         BATCH_SIZE=64,
-        NUM_EPOCHS=200,
+        MAX_EPOCHS=200,
         BALANCE_CLASSES=True,
         VAL_INTERVAL=1,
         WEIGHTS_SAVE_INTERVAL=1,
@@ -95,8 +95,8 @@ def training_callback(base_cfg, data_config):
     cfg=Config()
     train(cfg)
 
-def make_training_app(function=training_callback,columns=[4, 4],window_size=(1600,800)):
-    base_config=get_base_config()
+def make_training_app(function=training_callback,columns=[4, 4],window_size=(1600,800),train_dir='',val_dir=''):
+    base_config=get_base_config(train_dir=train_dir,val_dir=val_dir)
     data_config=get_data_config()
     app = make_app(function=function, args=(base_config, data_config), columns=columns,window_size=window_size)
     return app
